import 'dart:convert';

import 'package:codable/codable.dart';
import 'package:decimal/decimal.dart';
import 'package:meta/meta.dart';

import 'types.dart';

export 'types.dart';

part 'src/api/messages/balance.dart';
part 'src/api/messages/beneficiary.dart';
part 'src/api/messages/conversion.dart';
part 'src/api/messages/payment.dart';
part 'src/api/messages/rate.dart';

/// Parses a [bool] from [String]. Returns null if [value] is null.
/// Returns false if [value] is not 'true';
bool boolParse(String value) => value == null ? null : value.toLowerCase() == 'true';

/// Parses a [Decimal] from [String]. Returns null if [value] is null.
/// Throws [FormatException] if [value] is not a valid decimal format.
Decimal decimalParse(String value) => value == null ? null : new Decimal.parse(value);

/// Parses a [DateTime] from [String]. Returns null if [value] is null.
/// Throws [FormatException] if [value] is not a valid date time format.
DateTime dateTimeParse(String value) => value == null ? null : DateTime.parse(value);

/// Shorthand class for a [Coding] object that does not implement encode.
abstract class Decoding extends Coding {
  /// Not implemented. Do not use.
  @override
  void encode(KeyedArchive object) {
    throw UnimplementedError();
  }
}

/// Shorthand class for a [Coding] object that does not implement decode.
abstract class Encoding extends Coding {
  /// Not implemented. Do not use.
  @override
  // ignore: must_call_super
  void decode(KeyedArchive object) {
    throw UnimplementedError();
  }
}
