part of '../../../messages.dart';

class CreateConversion extends Encoding {
  final String buyCurrency;
  final String sellCurrency;
  final FixedSide fixedSide;
  final Decimal amount;
  final bool termAgreement;

  final String reason;

  CreateConversion({
    @required this.buyCurrency,
    @required this.sellCurrency,
    @required this.fixedSide,
    @required this.amount,
    @required this.termAgreement,
    this.reason,
  });

  @override
  void encode(KeyedArchive object) {
    object
      ..encode('buy_currency', buyCurrency)
      ..encode('sell_currency', sellCurrency)
      ..encode('fixed_side', fixedSide.id)
      ..encode('amount', amount.toString())
      ..encode('term_agreement', termAgreement)
      ..encode('reason', reason);
  }
}

class Conversion extends Decoding {
  String id;
  DateTime settlementDate;
  DateTime conversionDate;
  DateTime createdAt;
  DateTime updatedAt;
  String status;
  String buyCurrency;
  String sellCurrency;
  Decimal clientBuyAmount;
  Decimal clientSellAmount;
  FixedSide fixedSide;
  Decimal coreRate;

  @override
  void decode(KeyedArchive object) {
    super.decode(object);
    id = object.decode('id');
    settlementDate = dateTimeParse(object.decode('settlement_date'));
    conversionDate = dateTimeParse(object.decode('conversion_date'));
    createdAt = dateTimeParse(object.decode('created_at'));
    updatedAt = dateTimeParse(object.decode('updated_at'));
    status = object.decode('status');

    /// Currency code (ISO 4217)
    buyCurrency = object.decode('buy_currency');

    /// Currency code (ISO 4217)
    sellCurrency = object.decode('sell_currency');
    clientBuyAmount = decimalParse(object.decode('client_buy_amount'));
    clientSellAmount = decimalParse(object.decode('client_sell_amount'));
    fixedSide = FixedSide.fromString(object.decode('fixed_side'));
    coreRate = decimalParse(object.decode('core_rate'));
  }
}
