part of '../../../messages.dart';

class CreatePayment extends Encoding {
  final String currency;
  final String beneficiaryId;
  final Decimal amount;
  final String reason;
  final String reference;

  final String paymentDate;
  final PaymentType paymentType;
  final String conversionId;
  final EntityType payerEntityType;
  final String payerCompanyName;
  final String payerFirstName;
  final String payerLastName;
  final String payerCity;
  final String payerAddress;
  final String payerPostcode;
  final String payerStateOrProvince;
  final String payerCountry;
  final String payerDateOfBirth;
  final IdentificationType payerIdentificationType;
  final String payerIdentificationValue;
  final String uniqueRequestId;
  final String ultimateBeneficiaryName;
  final String onBehalfOf;

  CreatePayment({
    @required this.currency,
    @required this.beneficiaryId,
    @required this.amount,
    @required this.reason,
    @required this.reference,
    this.paymentDate,
    this.paymentType: PaymentType.regular,
    this.conversionId,
    this.payerEntityType,
    this.payerCompanyName,
    this.payerFirstName,
    this.payerLastName,
    this.payerCity,
    this.payerAddress,
    this.payerPostcode,
    this.payerStateOrProvince,
    this.payerCountry,
    this.payerDateOfBirth,
    this.payerIdentificationType,
    this.payerIdentificationValue,
    this.uniqueRequestId,
    this.ultimateBeneficiaryName,
    this.onBehalfOf,
  });

  @override
  void encode(KeyedArchive object) {
    object
      ..encode('currency', currency)
      ..encode('beneficiary_id', beneficiaryId)
      ..encode('amount', amount.toString())
      ..encode('reason', reason)
      ..encode('reference', reference)
      ..encode('payment_date', paymentDate)
      ..encode('payment_type', paymentType?.id)
      ..encode('conversion_id', conversionId)
      ..encode('payer_entity_type', payerEntityType?.id)
      ..encode('payer_company_name', payerCompanyName)
      ..encode('payer_first_name', payerFirstName)
      ..encode('payer_last_name', payerLastName)
      ..encode('payer_city', payerCity)
      ..encode('payer_address', payerAddress)
      ..encode('payer_postcode', payerPostcode)
      ..encode('payer_state_or_province', payerStateOrProvince)
      ..encode('payer_country', payerCountry)
      ..encode('payer_date_of_birth', payerDateOfBirth)
      ..encode('payer_identification_type', payerIdentificationType?.id)
      ..encode('payer_identification_value', payerIdentificationValue)
      ..encode('unique_request_id', uniqueRequestId)
      ..encode('ultimate_beneficiary_name', ultimateBeneficiaryName)
      ..encode('on_behalf_of', onBehalfOf);
  }
}

class Payment extends Decoding {
  String id;
  Decimal amount;
  String beneficiaryId;
  String currency;
  String reference;
  String reason;
  String status;
  String creatorContactId;
  PaymentType paymentType;
  String paymentDate;
  String transferredAt;
  String authorisationStepsRequired;
  String lastUpdaterContactId;
  String shortReference;
  String conversionId;
  String failureReason;
  String payerId;
  String payerDetailsSource;
  DateTime createdAt;
  DateTime updatedAt;
  String paymentGroupId;
  String uniqueRequestId;
  Decimal failureReturnedAmount;
  String ultimateBeneficiaryName;

  @override
  void decode(KeyedArchive object) {
    super.decode(object);
    id = object.decode('id');
    amount = decimalParse(object.decode('amount'));
    beneficiaryId = object.decode('beneficiary_id');

    /// Currency code (ISO 4217)
    currency = object.decode('currency');
    reference = object.decode('reference');
    reason = object.decode('reason');
    status = object.decode('status');
    creatorContactId = object.decode('creator_contact_id');
    paymentType = PaymentType.fromString(object.decode('payment_type'));
    paymentDate = object.decode('payment_date');
    transferredAt = object.decode('transferred_at');
    authorisationStepsRequired = object.decode('authorisation_steps_required');
    lastUpdaterContactId = object.decode('last_updater_contact_id');
    shortReference = object.decode('short_reference');
    conversionId = object.decode('conversion_id');
    failureReason = object.decode('failure_reason');
    payerId = object.decode('payer_id');
    payerDetailsSource = object.decode('payer_details_source');
    createdAt = dateTimeParse(object.decode('created_at'));
    updatedAt = dateTimeParse(object.decode('updated_at'));
    paymentGroupId = object.decode('payment_group_id');
    uniqueRequestId = object.decode('unique_request_id');
    failureReturnedAmount = decimalParse(object.decode('failure_returned_amount'));
  }
}
