import 'package:currency_cloud/currency_cloud.dart';
import 'package:test/test.dart';

main() {
  group('boolParse', () {
    test('returns null if the value is null', () async {
      expect(boolParse(null), null);
    });
    test('returns correct bool', () async {
      expect(boolParse('true'), isTrue);
      expect(boolParse('false'), isFalse);
    });
    test('ignores case', () async {
      expect(boolParse('TRUE'), isTrue);
      expect(boolParse('FALSE'), isFalse);
    });
    test('returns false for every value that is not true', () async {
      expect(boolParse('FOO'), isFalse);
    });
  });
  group('decimalParse', () {
    test('returns null if the value is null', () async {
      expect(decimalParse(null), null);
    });
    test('returns correct decimal', () async {
      expect(decimalParse('10.00').toDouble(), 10.00);
      expect(decimalParse('12.345').toDouble(), 12.345);
      expect(decimalParse('1').toDouble(), 1.00);
    });
    test('throws FormatException for invalid values', () async {
      expect(() => decimalParse('FOO'), throwsFormatException);
    });
  });
  group('dateTimeParse', () {
    test('returns null if the value is null', () async {
      expect(dateTimeParse(null), null);
    });
    test('returns correct decimal', () async {
      expect(dateTimeParse('2018-07-24T14:30:12+00:00').millisecondsSinceEpoch, 1532442612000);
      expect(dateTimeParse('2018-07-24').millisecondsSinceEpoch, closeTo(1532442612000, 86400000));
    });
    test('throws FormatException for invalid values', () async {
      expect(() => dateTimeParse('FOO'), throwsFormatException);
    });
  });
}
