import 'package:codable/codable.dart';
import 'package:currency_cloud/currency_cloud.dart';
import 'package:test/test.dart';

import '../test_data.dart';

main() {
  group('CreateBeneficiary', () {
    test('properly encodes all values', () async {
      final createBeneficiary = new CreateBeneficiary(
        bankAccountHolderName: 'My Test Account Holder',
        name: 'My Test Beneficiary',
        bankCountry: 'GB',
        currency: 'GBP',
      );

      final archive = KeyedArchive.archive(createBeneficiary);

      expect(archive['bank_account_holder_name'], createBeneficiary.bankAccountHolderName);
      expect(archive['name'], createBeneficiary.name);
      expect(archive['bank_country'], createBeneficiary.bankCountry);
      expect(archive['currency'], createBeneficiary.currency);
    });
  });

  group('Beneficiary', () {
    test('properly decodes all values', () async {
      final json = getJson(beneficiaryJson);
      final archive = KeyedArchive.unarchive(json);
      final conversion = Beneficiary()..decode(archive);

      expect(conversion.id, json['id']);
      expect(conversion.bankAccountHolderName, json['bank_account_holder_name']);
      expect(conversion.name, json['name']);
      expect(conversion.email, json['email']);
      expect(
          conversion.paymentTypes, json['payment_types'].cast<String>().map((String v) => PaymentType.fromString(v)));
      expect(conversion.beneficiaryAddress, json['beneficiary_address']);
      expect(conversion.beneficiaryCountry, json['beneficiary_country']);
      expect(conversion.beneficiaryEntityType, json['beneficiary_entity_type']);
      expect(conversion.beneficiaryCompanyName, json['beneficiary_company_name']);
      expect(conversion.beneficiaryFirstName, json['beneficiary_first_name']);
      expect(conversion.beneficiaryLastName, json['beneficiary_last_name']);
      expect(conversion.beneficiaryCity, json['beneficiary_city']);
      expect(conversion.beneficiaryPostcode, json['beneficiary_postcode']);
      expect(conversion.beneficiaryStateOrProvince, json['beneficiary_state_or_province']);
      expect(conversion.beneficiaryDateOfBirth, json['beneficiary_date_of_birth']);
      expect(conversion.beneficiaryIdentificationType, json['beneficiary_identification_type']);
      expect(conversion.beneficiaryIdentificationValue, json['beneficiary_identification_value']);
      expect(conversion.bankCountry, json['bank_country']);
      expect(conversion.bankName, json['bank_name']);
      expect(conversion.bankAccountType, json['bank_account_type']);
      expect(conversion.currency, json['currency']);
      expect(conversion.accountNumber, json['account_number']);
      expect(conversion.routingCodeType1, RoutingCodeType.fromString(json['routing_code_type_1'] as String));
      expect(conversion.routingCodeValue1, json['routing_code_value_1']);
      expect(conversion.routingCodeType2, json['routing_code_type_2']);
      expect(conversion.routingCodeValue2, json['routing_code_value_2']);
      expect(conversion.bicSwift, json['bic_swift']);
      expect(conversion.iban, json['iban']);
      expect(conversion.defaultBeneficiary, boolParse(json['default_beneficiary'] as String));
      expect(conversion.creatorContactId, json['creator_contact_id']);
      expect(conversion.bankAddress, json['bank_address']);
      expect(conversion.createdAt, DateTime.parse(json['created_at'] as String));
      expect(conversion.updatedAt, DateTime.parse(json['updated_at'] as String));
      expect(conversion.beneficiaryExternalReference, json['beneficiary_external_reference']);
    });
  });
}
