import 'package:codable/codable.dart';
import 'package:currency_cloud/currency_cloud.dart';
import 'package:decimal/decimal.dart';
import 'package:test/test.dart';

import '../test_data.dart';

main() {
  group('CreateConversion', () {
    test('properly encodes all values', () async {
      final createConversion = new CreateConversion(
        buyCurrency: 'USD',
        sellCurrency: 'EUR',
        fixedSide: FixedSide.buy,
        amount: new Decimal.parse('123.45'),
        termAgreement: true,
        reason: 'just because',
      );

      final archive = KeyedArchive.archive(createConversion);

      expect(archive['buy_currency'], createConversion.buyCurrency);
      expect(archive['sell_currency'], createConversion.sellCurrency);
      expect(archive['fixed_side'], createConversion.fixedSide.id);
      expect(archive['amount'], createConversion.amount.toString());
      expect(archive['term_agreement'], createConversion.termAgreement);
      expect(archive['reason'], createConversion.reason);
    });
  });

  group('Conversion', () {
    test('properly decodes all values', () async {
      final json = getJson(conversionJson);
      final archive = KeyedArchive.unarchive(json);
      final conversion = Conversion()..decode(archive);

      expect(conversion.id, json['id']);
      expect(conversion.settlementDate, DateTime.parse(json['settlement_date'] as String));
      expect(conversion.conversionDate, DateTime.parse(json['conversion_date'] as String));
      expect(conversion.createdAt, DateTime.parse(json['created_at'] as String));
      expect(conversion.updatedAt, DateTime.parse(json['updated_at'] as String));
      expect(conversion.status, json['status']);
      expect(conversion.buyCurrency, json['buy_currency'] as String);
      expect(conversion.sellCurrency, json['sell_currency'] as String);
      expect(conversion.clientBuyAmount, new Decimal.parse(json['client_buy_amount'] as String));
      expect(conversion.clientSellAmount, new Decimal.parse(json['client_sell_amount'] as String));
      expect(conversion.fixedSide, FixedSide.fromString(json['fixed_side'] as String));
      expect(conversion.coreRate, new Decimal.parse(json['core_rate'] as String));
    });
  });
}
