import 'package:codable/codable.dart';
import 'package:currency_cloud/currency_cloud.dart';
import 'package:decimal/decimal.dart';
import 'package:test/test.dart';

import '../test_data.dart';

main() {
  group('CreatePayment', () {
    test('properly encodes all values', () async {
      final createPayment = new CreatePayment(
        currency: 'GBP',
        beneficiaryId: '9b40b6e7-5d18-42ac-87bc-5c5f774e91ab',
        amount: new Decimal.parse('10.00'),
        reason: 'This is a test payment.',
        reference: 'This is a test reference.',
      );

      final archive = KeyedArchive.archive(createPayment);

      expect(archive['currency'], createPayment.currency);
      expect(archive['beneficiary_id'], createPayment.beneficiaryId);
      expect(archive['amount'], createPayment.amount.toString());
      expect(archive['reason'], createPayment.reason);
      expect(archive['reference'], createPayment.reference);
    });
  });

  group('Payment', () {
    test('properly decodes all values', () async {
      final json = getJson(paymentJson);
      final archive = KeyedArchive.unarchive(json);
      final payment = Payment()..decode(archive);

      expect(payment.id, json['id']);
      expect(payment.amount, new Decimal.parse(json['amount'] as String));
      expect(payment.beneficiaryId, json['beneficiary_id']);
      expect(payment.currency, json['currency'] as String);
      expect(payment.reference, json['reference']);
      expect(payment.reason, json['reason']);
      expect(payment.status, json['status']);
      expect(payment.creatorContactId, json['creator_contact_id']);
      expect(payment.paymentType, PaymentType.fromString(json['payment_type'] as String));
      expect(payment.paymentDate, json['payment_date']);
      expect(payment.transferredAt, json['transferred_at']);
      expect(payment.authorisationStepsRequired, json['authorisation_steps_required']);
      expect(payment.lastUpdaterContactId, json['last_updater_contact_id']);
      expect(payment.shortReference, json['short_reference']);
      expect(payment.conversionId, json['conversion_id']);
      expect(payment.failureReason, json['failure_reason']);
      expect(payment.payerId, json['payer_id']);
      expect(payment.payerDetailsSource, json['payer_details_source']);
      expect(payment.createdAt, DateTime.parse(json['created_at'] as String));
      expect(payment.updatedAt, DateTime.parse(json['updated_at'] as String));
      expect(payment.paymentGroupId, json['payment_group_id']);
      expect(payment.uniqueRequestId, json['unique_request_id']);
      expect(payment.failureReturnedAmount, new Decimal.parse(json['failure_returned_amount'] as String));
      expect(payment.ultimateBeneficiaryName, json['ultimate_beneficiary_name']);
    });
  });
}
